##  Relations
Relations for the new AI agent fact sheet and business application fact sheet:
Relation | Type | Description
---|---|---
Business Applications | Many-to-many |  On the business application fact sheet: Which AI agents run on this business application? On the AI agent fact sheet: Which business applications does this AI agent run on?
Business Capabilities | Many-to-many | Business capabilities that the AI agent supports
IT Components | Many-to-many | Services, software, and hardware the AI agent is using
Platforms | Many-to-many | Platforms the AI agents runs on
Business Contexts | Many-to-many | Business contexts the AI agent supports
Data Objects | Many-to-many | Data objects that the AI agents creates, modifies, or requires
Provided Interfaces | Many-to-many | Interfaces provided by the AI agent
Consumed Interfaces | Many-to-many | Interfaces used by the AI agent
Organizations | Many-to-many | AI agent users
Initiatives | Many-to-many | Initiatives that affect the AI agent


YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
